Ludology |travis| |appveyor| |codecov| |readthedocs|
====================================================

``Ludology`` is a package for the study of combinatorial game theory.


.. |travis| image:: https://travis-ci.org/Autoplectic/ludology.svg?branch=master
   :target: https://travis-ci.org/Autoplectic/ludology
   :alt: build status

.. |appveyor| image:: https://ci.appveyor.com/api/projects/status/to2kso5s9a07ehbe?svg=true
   :target: https://ci.appveyor.com/project/Autoplectic/ludology/branch/master
   :alt: build status

.. |codecov| image:: https://codecov.io/gh/Autoplectic/ludology/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/Autoplectic/ludology
  :alt: test coverage

.. |readthedocs| image:: https://readthedocs.org/projects/ludology/badge/?version=latest
  :target: https://ludology.readthedocs.io/en/latest/?badge=latest
  :alt: documentation status
